@@ -1,7 +1,8 @@
 #!/usr/bin/env ruby
 
 # ncurses-ruby is a ruby module for accessing the FSF's ncurses library
-# (C) 2002 Tobias Peters <t-peters@users.berlios.de>
+# (C) 2002, 2004 Tobias Peters <t-peters@users.berlios.de>
+# (C) 2005, 2009 Tobias Herzke
 #
 # This module is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,7 +18,7 @@
 # License along with this module; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 
-# $Id: extconf.rb,v 1.9 2003/03/22 20:00:52 t-peters Exp $
+# $Id: extconf.rb,v 1.14 2009/05/03 14:13:27 t-peters Exp $
 
 require "mkmf"
 
@@ -25,6 +26,8 @@ $CFLAGS  += " -g"
 $CXXFLAGS  = $CFLAGS
 
 have_header("unistd.h")
+have_header("locale.h")
+
 if have_header("ncurses.h")
   curses_header = "ncurses.h"
 elsif have_header("ncurses/curses.h")
@@ -122,5 +125,13 @@ puts "checking for the panel library..."
 if have_header("panel.h")
   have_library("panel", "panel_hidden")
 end
+puts "checking for the form library..."
+if have_header("form.h")
+  have_library("form", "new_form")
+end
+puts "checking for the menu library..."
+if have_header("menu.h")
+  have_library("menu", "new_menu")
+end
 
-create_makefile('ncurses')
+create_makefile('ncurses_bin')
