@@ -18,7 +18,7 @@
  *  License along with this module; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  *
- * $Id: ncurses_wrap.c,v 1.16 2009/05/03 20:37:26 t-peters Exp $
+ * $Id: ncurses_wrap.c,v 1.18 2009/07/31 10:49:24 t-peters Exp $
  *
  * This file was adapted from the original ncurses header file which
  * has the following copyright statements:
@@ -210,7 +210,7 @@ init_constants_2(void)
 /// Portable (1.8,1.9) determination of array length (calling #length)
 long rbncurs_array_length(VALUE array)
 {
-  return NUM2LONG(funcall(array, rb_intern("length"), 0));
+  return NUM2LONG(rb_funcall(array, rb_intern("length"), 0));
 }
 
 VALUE   wrap_window(WINDOW* window)
